@@ -1,5 +1,3 @@
-# coding: utf-8
-from __future__ import unicode_literals
 from eulxml import xmlmap
 from eulxml.xmlmap import XmlObject
 from eulxml.xmlmap import StringField as SF
