@@ -1,5 +1,3 @@
-# coding: utf-8
-from __future__ import unicode_literals
 import unittest
 from eulxml.xmlmap  import load_xmlobject_from_string
 from bdrxml import mods
